summaryrefslogtreecommitdiffstats
path: root/src/gallium/drivers/ilo/ilo_screen.c
diff options
context:
space:
mode:
authorChia-I Wu <olvaffe@gmail.com>2014-04-13 23:37:04 +0800
committerChia-I Wu <olvaffe@gmail.com>2014-04-14 20:45:04 +0800
commit6c6bd796adda4173ebaf494d6cd2a96d511f1ea3 (patch)
treeb6b98c120b5864cec8ef4a5192a2a504fc225bd7 /src/gallium/drivers/ilo/ilo_screen.c
parent01e3e82a56310932667c60bcca9cc9fdfd8b87c4 (diff)
downloadexternal_mesa3d-6c6bd796adda4173ebaf494d6cd2a96d511f1ea3.zip
external_mesa3d-6c6bd796adda4173ebaf494d6cd2a96d511f1ea3.tar.gz
external_mesa3d-6c6bd796adda4173ebaf494d6cd2a96d511f1ea3.tar.bz2
ilo: scripted conversion to genhw headers
Hopefully my four hundred line sed script is correct.
Diffstat (limited to 'src/gallium/drivers/ilo/ilo_screen.c')
-rw-r--r--src/gallium/drivers/ilo/ilo_screen.c6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/gallium/drivers/ilo/ilo_screen.c b/src/gallium/drivers/ilo/ilo_screen.c
index 8c2e04e..c368fe5 100644
--- a/src/gallium/drivers/ilo/ilo_screen.c
+++ b/src/gallium/drivers/ilo/ilo_screen.c
@@ -28,7 +28,7 @@
#include "util/u_format_s3tc.h"
#include "vl/vl_decoder.h"
#include "vl/vl_video_buffer.h"
-#include "genhw/genhw.h" /* for TIMESTAMP */
+#include "genhw/genhw.h" /* for GEN6_REG_TIMESTAMP */
#include "intel_winsys.h"
#include "ilo_context.h"
@@ -425,7 +425,7 @@ ilo_get_param(struct pipe_screen *screen, enum pipe_cap param)
case PIPE_CAP_TEXTURE_BORDER_COLOR_QUIRK:
return 0;
case PIPE_CAP_MAX_TEXTURE_BUFFER_SIZE:
/* a BRW_SURFACE_BUFFER can have up to 2^27 elements */
return 1 << 27;
case PIPE_CAP_MAX_VIEWPORTS:
return ILO_MAX_VIEWPORTS;
@@ -501,7 +501,7 @@ ilo_get_timestamp(struct pipe_screen *screen)
uint32_t dw[2];
} timestamp;
- intel_winsys_read_reg(is->winsys, TIMESTAMP, &timestamp.val);
+ intel_winsys_read_reg(is->winsys, GEN6_REG_TIMESTAMP, &timestamp.val);
/*
* From the Ivy Bridge PRM, volume 1 part 3, page 107:
@@ -425,7 +425,7 @@ ilo_get_param(struct pipe_screen *screen, enum pipe_cap param)
return 0;
case PIPE_CAP_MAX_TEXTURE_BUFFER_SIZE:
- /* a BRW_SURFACE_BUFFER can have up to 2^27 elements */
+ /* a GEN6_SURFTYPE_BUFFER can have up to 2^27 elements */
return 1 << 27;
case PIPE_CAP_MAX_VIEWPORTS: